@@ -2,8 +2,11 @@
 from .glitch import GlitchBeautifier
 from .cartoonise import CartooniseBeautifier
 from .cartoongan import CartoonGanBeautifier
+from .beziercurve import BezierCurveBeautifier
 from .photomosaic import PhotomosaicBeautifier
 from .characterize import CharacterizeBeautifier
 from .douyineffect import DouyinEffectBeautifier
 from .pencildrawing import PencilDrawingBeautifier
-from .fastneuralstyletransfer import FastNeuralStyleTransferBeautifier
\ No newline at end of file
+from .cartoonizeface import CartoonizeFaceBeautifier
+from .fastneuralstyletransfer import FastNeuralStyleTransferBeautifier
+from .geneticfitting import GeneticFittingCircleBeautifier, GeneticFittingPolygonBeautifier
\ No newline at end of file
